/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                    TERCER GRADO DE SECUNDARIA (Excale 09)
/*
/*                          **** BIOLOGA ****
/*
/*                     Ciclo escolar evaluado: 2007 - 2008
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE BIOLOGA
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale09_2008_Alum_Bio.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale09_2008_Alum_Bio.txt
/*         as como el archivo Excale09_2008_Alum_Bio.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale09_2008_Alum_Bio.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale09_2008_Alum_Bio.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 16 DE MARZO DEL 2010
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale09_2008_Alum_Bio.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbana Pblica"
                       2         ="Rural Pblica"
                       3         ="Educacin Indgena"
                       4         ="Curso Comunitario"
                       5         ="Privada"
                       6         ="General"
                       7         ="Tcnica"
                       8         ="Telesecundaria"
                       9         ="Privada";
     VALUE $modF       "GRAL"    ="General"
                       "TEC"     ="Tcnica"
                       "TV"      ="Telesecundaria"
                       "PRIV"    ="Privada";
     VALUE $mageb05F   "R"       ="Escuela rural"
                       "UA"      ="Escuela urbana de alta marginacin"
                       "UB"      ="Escuela urbana de baja marginacin"
                       "NA"      ="No aplica";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="14 aos o menos"
                       2         ="15 aos"
                       3         ="16 aos"
                       4         ="17 aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE na1_d25f    0         ="Fallo"
                       1         ="Acierto (pregunta dicotmica)/Acierto parcial (Pregunta politmica)"
                       2         ="Acierto total (pregunta dicotmica)"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       6         ="Reactivo no administrado por error de impresin"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)";
RUN;



DATA INEE.Excale09_2008_Alum_Bio;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $19
       id_mod             3
       mod                $4
       mageb05            $2
       estrato            $7
       entest             $6
       alumno             6
       id_instr           $16
       sexo               3
       edad               8
       edadc              3
       edadn              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       sna_01             3
       sna_02             3
       sna_03             3
       sna_04             3
       sna_05             3
       sna_06             3
       sna_07             3
       sna_08             3
       sna_09             3
       sna_10             3
       sna_11             3
       sna_12             3
       sna_13             3
       sna_14             3
       sna_15             3
       sna_16             3
       sna_17             3
       sna_18             3
       sna_19             3
       sna_20             3
       sna_21             3
       sna_22             3
       sna_23             3
       sna_24             3
       sna_25             3
       snb_01             3
       snb_02             3
       snb_03             3
       snb_04             3
       snb_05             3
       snb_06             3
       snb_07             3
       snb_08             3
       snb_09             3
       snb_10             3
       snb_11             3
       snb_12             3
       snb_13             3
       snb_14             3
       snb_15             3
       snb_16             3
       snb_17             3
       snb_18             3
       snb_19             3
       snb_20             3
       snb_21             3
       snb_22             3
       snb_23             3
       snb_24             3
       snb_25             3
       snc_01             3
       snc_02             3
       snc_03             3
       snc_04             3
       snc_05             3
       snc_06             3
       snc_07             3
       snc_08             3
       snc_09             3
       snc_10             3
       snc_11             3
       snc_12             3
       snc_13             3
       snc_14             3
       snc_15             3
       snc_16             3
       snc_17             3
       snc_18             3
       snc_19             3
       snc_20             3
       snc_21             3
       snc_22             3
       snc_23             3
       snc_24             3
       snc_25             3
       snd_01             3
       snd_02             3
       snd_03             3
       snd_04             3
       snd_05             3
       snd_06             3
       snd_07             3
       snd_08             3
       snd_09             3
       snd_10             3
       snd_11             3
       snd_12             3
       snd_13             3
       snd_14             3
       snd_15             3
       snd_16             3
       snd_17             3
       snd_18             3
       snd_19             3
       snd_20             3
       snd_21             3
       snd_22             3
       snd_23             3
       snd_24             3
       snd_25             3
       pv1bio             8
       pv2bio             8
       pv3bio             8
       pv4bio             8
       pv5bio             8
       bionvl1            3
       bionvl2            3
       bionvl3            3
       bionvl4            3
       bionvl5            3
       bionvlb1           3
       bionvlb2           3
       bionvlb3           3
       bionvlb4           3
       bionvlb5           3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
 ;

INFILE alum MISSOVER LINESIZE = 1134;
   INPUT
       nacional            1 - 1
       escuela             2 - 5
       id_ent              6 - 7
       nom_ent             8 - 26
       id_mod             27 - 27
       mod                28 - 31
       mageb05            32 - 33
       estrato            34 - 40
       entest             41 - 46
       alumno             47 - 52
       id_instr           53 - 68
       sexo               69 - 69
       edad               70 - 80
       edadc              81 - 81
       edadn              82 - 82
       edad_ac            83 - 84
       mes_nac            85 - 86
       w_alu              87 - 97
       docente            98 - 102
       sna_01            103 - 103
       sna_02            104 - 104
       sna_03            105 - 105
       sna_04            106 - 106
       sna_05            107 - 107
       sna_06            108 - 108
       sna_07            109 - 109
       sna_08            110 - 110
       sna_09            111 - 111
       sna_10            112 - 112
       sna_11            113 - 113
       sna_12            114 - 114
       sna_13            115 - 115
       sna_14            116 - 116
       sna_15            117 - 117
       sna_16            118 - 118
       sna_17            119 - 119
       sna_18            120 - 120
       sna_19            121 - 121
       sna_20            122 - 122
       sna_21            123 - 123
       sna_22            124 - 124
       sna_23            125 - 125
       sna_24            126 - 126
       sna_25            127 - 127
       snb_01            128 - 128
       snb_02            129 - 129
       snb_03            130 - 130
       snb_04            131 - 131
       snb_05            132 - 132
       snb_06            133 - 133
       snb_07            134 - 134
       snb_08            135 - 135
       snb_09            136 - 136
       snb_10            137 - 137
       snb_11            138 - 138
       snb_12            139 - 139
       snb_13            140 - 140
       snb_14            141 - 141
       snb_15            142 - 142
       snb_16            143 - 143
       snb_17            144 - 144
       snb_18            145 - 145
       snb_19            146 - 146
       snb_20            147 - 147
       snb_21            148 - 148
       snb_22            149 - 149
       snb_23            150 - 150
       snb_24            151 - 151
       snb_25            152 - 152
       snc_01            153 - 153
       snc_02            154 - 154
       snc_03            155 - 155
       snc_04            156 - 156
       snc_05            157 - 157
       snc_06            158 - 158
       snc_07            159 - 159
       snc_08            160 - 160
       snc_09            161 - 161
       snc_10            162 - 162
       snc_11            163 - 163
       snc_12            164 - 164
       snc_13            165 - 165
       snc_14            166 - 166
       snc_15            167 - 167
       snc_16            168 - 168
       snc_17            169 - 169
       snc_18            170 - 170
       snc_19            171 - 171
       snc_20            172 - 172
       snc_21            173 - 173
       snc_22            174 - 174
       snc_23            175 - 175
       snc_24            176 - 176
       snc_25            177 - 177
       snd_01            178 - 178
       snd_02            179 - 179
       snd_03            180 - 180
       snd_04            181 - 181
       snd_05            182 - 182
       snd_06            183 - 183
       snd_07            184 - 184
       snd_08            185 - 185
       snd_09            186 - 186
       snd_10            187 - 187
       snd_11            188 - 188
       snd_12            189 - 189
       snd_13            190 - 190
       snd_14            191 - 191
       snd_15            192 - 192
       snd_16            193 - 193
       snd_17            194 - 194
       snd_18            195 - 195
       snd_19            196 - 196
       snd_20            197 - 197
       snd_21            198 - 198
       snd_22            199 - 199
       snd_23            200 - 200
       snd_24            201 - 201
       snd_25            202 - 202
       pv1bio            203 - 210
       pv2bio            211 - 218
       pv3bio            219 - 226
       pv4bio            227 - 234
       pv5bio            235 - 242
       bionvl1           243 - 243
       bionvl2           244 - 244
       bionvl3           245 - 245
       bionvl4           246 - 246
       bionvl5           247 - 247
       bionvlb1          248 - 248
       bionvlb2          249 - 249
       bionvlb3          250 - 250
       bionvlb4          251 - 251
       bionvlb5          252 - 252
       wvarstrr          253 - 254
       w_fstr1           255 - 265
       w_fstr2           266 - 276
       w_fstr3           277 - 287
       w_fstr4           288 - 298
       w_fstr5           299 - 309
       w_fstr6           310 - 320
       w_fstr7           321 - 331
       w_fstr8           332 - 342
       w_fstr9           343 - 353
       w_fstr10          354 - 364
       w_fstr11          365 - 375
       w_fstr12          376 - 386
       w_fstr13          387 - 397
       w_fstr14          398 - 408
       w_fstr15          409 - 419
       w_fstr16          420 - 430
       w_fstr17          431 - 441
       w_fstr18          442 - 452
       w_fstr19          453 - 463
       w_fstr20          464 - 474
       w_fstr21          475 - 485
       w_fstr22          486 - 496
       w_fstr23          497 - 507
       w_fstr24          508 - 518
       w_fstr25          519 - 529
       w_fstr26          530 - 540
       w_fstr27          541 - 551
       w_fstr28          552 - 562
       w_fstr29          563 - 573
       w_fstr30          574 - 584
       w_fstr31          585 - 595
       w_fstr32          596 - 606
       w_fstr33          607 - 617
       w_fstr34          618 - 628
       w_fstr35          629 - 639
       w_fstr36          640 - 650
       w_fstr37          651 - 661
       w_fstr38          662 - 672
       w_fstr39          673 - 683
       w_fstr40          684 - 694
       w_fstr41          695 - 705
       w_fstr42          706 - 716
       w_fstr43          717 - 727
       w_fstr44          728 - 738
       w_fstr45          739 - 749
       w_fstr46          750 - 760
       w_fstr47          761 - 771
       w_fstr48          772 - 782
       w_fstr49          783 - 793
       w_fstr50          794 - 804
       w_fstr51          805 - 815
       w_fstr52          816 - 826
       w_fstr53          827 - 837
       w_fstr54          838 - 848
       w_fstr55          849 - 859
       w_fstr56          860 - 870
       w_fstr57          871 - 881
       w_fstr58          882 - 892
       w_fstr59          893 - 903
       w_fstr60          904 - 914
       w_fstr61          915 - 925
       w_fstr62          926 - 936
       w_fstr63          937 - 947
       w_fstr64          948 - 958
       w_fstr65          959 - 969
       w_fstr66          970 - 980
       w_fstr67          981 - 991
       w_fstr68          992 - 1002
       w_fstr69         1003 - 1013
       w_fstr70         1014 - 1024
       w_fstr71         1025 - 1035
       w_fstr72         1036 - 1046
       w_fstr73         1047 - 1057
       w_fstr74         1058 - 1068
       w_fstr75         1069 - 1079
       w_fstr76         1080 - 1090
       w_fstr77         1091 - 1101
       w_fstr78         1102 - 1112
       w_fstr79         1113 - 1123
       w_fstr80         1124 - 1134
;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       mageb05     = "ndice de marginacin urbana 2005"
       estrato     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       alumno      = "Identificador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       edad        = "Edad del alumno al mes de mayo de 2008, en aos (al momento de la aplicacin)"
       edadc       = "Edad del alumno al mes de mayo de 2008, codificada (al momento de la aplicacin)"
       edadn       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       sna_01      = "identificar las ventajas de recibir atencin mdica profesional"
       sna_02      = "Reconocer una consecuencia de la tala inmoderada"
       sna_03      = "Identificar una caracterstica del funcionamiento del tejido muscular"
       sna_04      = "Identificar una fuente de variabilidad gentica en un ejemplo dado"
       sna_05      = "Identificar la forma cientfica de entender una situacin dada"
       sna_06      = "Identificar una ventaja del uso del condn"
       sna_07      = "Identificar la relacin entre la diversidad biolgica y la evolucin orgnica"
       sna_08      = "Identificar las funciones de uno de los rganos del sistema nervioso central"
       sna_09      = "Relacionar el campo de estudio de la Ecologa con algunos problemas ambientales"
       sna_10      = "Identificar un men con los nutrimentos de una comida balanceada"
       sna_11      = "Reconocer uno de los efectos nocivos de la marihuana"
       sna_12      = "Reconocer una causa de la contaminacin del suelo"
       sna_13      = "Identificar los efectos nocivos del alcohol a la salud"
       sna_14      = "Identificar la aportacin de Schleiden y Schwann a la Biologa"
       sna_15      = "Reconocer la importancia de algunos compuestos orgnicos tiles en la medicina"
       sna_16      = "Reconocer la importancia de contar con informacin confiable en el ejercicio responsable de la sexualidad"
       sna_17      = "Identificar uno de los postulados de la Teora celular, mediante un ejemplo"
       sna_18      = "Identificar una caracterstica que distingue al ser  humano actual de los dems homnidos"
       sna_19      = "Identificar una funcin del sistema nervioso autnomo, a partir de un ejemplo"
       sna_20      = "Identificar una forma alternativa de generar energa elctrica que mitigue problemas ambientales"
       sna_21      = "Reconocer la importancia de los rboles en la produccin de oxgeno para la respiracin de los seres vivos"
       sna_22      = "Identificar la funcin de los cromosomas"
       sna_23      = "Identificar la funcin de un rgano del aparato sexual"
       sna_24      = "Identificar una accin que implica responsabilidad en el cuidado del planeta"
       sna_25      = "Distinguir entre la dominancia y la recesividad en un ejemplo dado"
       snb_01      = "Identificar la funcin de una de las glndulas del cuerpo humano"
       snb_02      = "Identificar el procedimiento principal con el que Leeuwenhoeck contribuy al avance del conocimiento cientfico"
       snb_03      = "Identificar un elemento qumico comn a todos los seres vivos"
       snb_04      = "Identificar una caracterstica de los virus"
       snb_05      = "Identificar los efectos de la disminucin de organismos consumidores en un ecosistema acutico"
       snb_06      = "Reconocer la importancia de la fotosntesis como fuente de oxgeno"
       snb_07      = "Identificar una de las aportaciones del uso del microscopio"
       snb_08      = "Identificar los resultados de un experimento con plantas"
       snb_09      = "Reconocer las caractersticas que distinguen a los seres vivos de los no vivos"
       snb_10      = "Identificar las ventajas de los distintos mtodos anticonceptivos"
       snb_11      = "Distinguir las diferencias entre la reproduccin sexual y la asexual"
       snb_12      = "Identificar la relacin de la Biologa con otras ciencias, a partir de una situacin dada"
       snb_13      = "Identificar una de las ventajas principales de la planificacin familiar"
       snb_14      = "Identificar cmo se afectan los ecosistemas por los cambios en los factores biticos y abiticos"
       snb_15      = "Identificar el proceso de especiacin, a partir de un ejemplo"
       snb_16      = "Identificar una ventaja de la inseminacin artificial"
       snb_17      = "Reconocer a las plantas como productoras de oxgeno"
       snb_18      = "Identificar las caractersticas de uno de los mtodos anticonceptivos"
       snb_19      = "Identificar la funcin de los tejidos de conduccin en los vegetales"
       snb_20      = "Identificar un ejemplo de adaptacin de un ser vivo"
       snb_21      = "Identificar una caracterstica de los cromosomas"
       snb_22      = "Identificar las caractersticas de un ecosistema dado"
       snb_23      = "Identificar cmo se transmite una enfermedad hereditaria"
       snb_24      = "Identificar una caracterstica de la planta del maz que la hace altamente domesticable"
       snb_25      = "Reconocer la importancia del nombre cientfico de los seres vivos"
       snc_01      = "Identificar un ejemplo de organismo auttrofo"
       snc_02      = "Distinguir un conocimiento subjetivo de uno objetivo, a partir de un ejemplo"
       snc_03      = "Reconocer uno de los avances de la Biologa que contribuye al mejoramiento de la salud"
       snc_04      = "Relacionar los rganos de la respiracin de los animales con el medio donde viven"
       snc_05      = "Distinguir una de las diferencias entre los seres vivos y los seres no vivos"
       snc_06      = "Identificar una de las medidas para reducir la contaminacin del suelo"
       snc_07      = "Reconocer una actividad que propici el avance de la anatoma en la Edad Media"
       snc_08      = "Distinguir los caracteres sexuales primarios de los secundarios en los hombres y en las mujeres"
       snc_09      = "Reconocer  el dao que ocasiona el manejo inadecuado de la electricidad al medio"
       snc_10      = "Identificar una de las ideas de Darwin sobre la evolucin"
       snc_11      = "Reconocer la importancia de conservar las distintas especies animales"
       snc_12      = "Identificar los principales sntomas de una infeccin de transmisin sexual"
       snc_13      = "Identificar la semejanza entre una de las etapas de la vida de las plantas y de los animales"
       snc_14      = "Identificar una causa natural de la prdida de la biodiversidad"
       snc_15      = "Identificar una ventaja de la clonacin"
       snc_16      = "Identificar una caracterstica distintiva entre la respiracin aerobia y la anaerobia"
       snc_17      = "Identificar en qu consiste el desarrollo embrionario"
       snc_18      = "Identificar el papel del ciclo del nitrgeno en los ecosistemas"
       snc_19      = "Identificar uno de los factores que propiciaron la diversificacin de los mamferos, a partir de la interpretacin de una grfica"
       snc_20      = "Identificar cmo acta la seleccin natural, a partir de un ejemplo"
       snc_21      = "Identificar una caracterstica de las clulas que se dividen por mitosis"
       snc_22      = "Identificar las caractersticas de las clulas eucariontes"
       snc_23      = "Reconocer la importancia de las protenas en la formacin de tejidos"
       snc_24      = "Identificar el papel de la testosterona en la aparicin de los caracteres sexuales secundarios"
       snc_25      = "Reconocer el papel de los cidos nucleicos en la transmisin de la herencia"
       snd_01      = "Identificar una semejanza entre la mitosis y la meiosis"
       snd_02      = "Identificar una de las aportaciones de Hooke a la Biologa"
       snd_03      = "Reconocer la importancia de los fsiles en la reconstruccin de la historia de la vida en el planeta"
       snd_04      = "Identificar una funcin de los glbulos rojos"
       snd_05      = "Identificar las fases de la mitosis"
       snd_06      = "Reconocer la importancia de los carbohidratos como el combustible principal de la clula"
       snd_07      = "Identificar una aportacin de la gentica que apoya la evolucin de los seres vivos"
       snd_08      = "Identificar los resultados a los que lleg Francisco Redi con sus experimentos"
       snd_09      = "Distinguir la diferencia entre factores biticos y abiticos"
       snd_10      = "Identificar una caracterstica de uno de  los reinos en que se clasifican los seres vivos"
       snd_11      = "Reconocer la importancia de los lpidos como energa de reserva"
       snd_12      = "Identificar uno de los factores que favorece la existencia de gran biodiversidad en el pas"
       snd_13      = "Identificar una dieta mal balanceada con base en el anlisis de un ejemplo dado"
       snd_14      = "Identificar una medida que ayude a prevenir enfermedades parasitarias"
       snd_15      = "Identificar la funcin de una de las estructuras celulares"
       snd_16      = "Identificar uno de los resultados del experimento sobre la teora fisicoqumica del origen de la vida"
       snd_17      = "Identificar alimentos ricos en protenas"
       snd_18      = "Calcular la fecha de la ovulacin, a partir de la del  inicio de la menstruacin"
       snd_19      = "Identificar una caracterstica del carbono"
       snd_20      = "Identificar la explicacin ms aceptada acerca del origen de la vida"
       snd_21      = "Identificar la funcin de las mitocondrias"
       snd_22      = "Identificar uno de los criterios para clasificar a los seres vivos"
       snd_23      = "Reconocer la importancia de la clasificacin de Linneo"
       snd_24      = "Reconocer la importancia de las aportaciones de Darwin y Mendel en el conocimiento de la evolucin y la herencia"
       snd_25      = "Identificar, con ayuda de un esquema, la funcin de uno de los rganos del aparato digestivo"
       pv1bio      = "Primer valor plausible de Biologa"
       pv2bio      = "Segundo valor plausible de Biologa"
       pv3bio      = "Tercer valor plausible de Biologa"
       pv4bio      = "Cuarto valor plausible de Biologa"
       pv5bio      = "Quinto valor plausible de Biologa"
       bionvl1     = "Nivel de logro en Biologa. Asociado a PV1BIO. (Cuatro niveles)"
       bionvl2     = "Nivel de logro en Biologa. Asociado a PV2BIO. (Cuatro niveles)"
       bionvl3     = "Nivel de logro en Biologa. Asociado a PV3BIO. (Cuatro niveles)"
       bionvl4     = "Nivel de logro en Biologa. Asociado a PV4BIO. (Cuatro niveles)"
       bionvl5     = "Nivel de logro en Biologa. Asociado a PV5BIO. (Cuatro niveles)"
       bionvlb1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Biologa. Asociado a PV1BIO."
       bionvlb2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Biologa. Asociado a PV2BIO."
       bionvlb3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Biologa. Asociado a PV3BIO."
       bionvlb4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Biologa. Asociado a PV4BIO."
       bionvlb5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Biologa. Asociado a PV5BIO."
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char19.
       id_mod             id_modF.
       mod                $modF.
       mageb05            mageb05F.
       estrato            $char7.
       entest             $char6.
       alumno             5.
       id_instr           $char16.
       sexo               sexoF.
       edad               edadF.
       edadc              edadcF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       sna_01             na1_d25f.
       sna_02             na1_d25f.
       sna_03             na1_d25f.
       sna_04             na1_d25f.
       sna_05             na1_d25f.
       sna_06             na1_d25f.
       sna_07             na1_d25f.
       sna_08             na1_d25f.
       sna_09             na1_d25f.
       sna_10             na1_d25f.
       sna_11             na1_d25f.
       sna_12             na1_d25f.
       sna_13             na1_d25f.
       sna_14             na1_d25f.
       sna_15             na1_d25f.
       sna_16             na1_d25f.
       sna_17             na1_d25f.
       sna_18             na1_d25f.
       sna_19             na1_d25f.
       sna_20             na1_d25f.
       sna_21             na1_d25f.
       sna_22             na1_d25f.
       sna_23             na1_d25f.
       sna_24             na1_d25f.
       sna_25             na1_d25f.
       snb_01             na1_d25f.
       snb_02             na1_d25f.
       snb_03             na1_d25f.
       snb_04             na1_d25f.
       snb_05             na1_d25f.
       snb_06             na1_d25f.
       snb_07             na1_d25f.
       snb_08             na1_d25f.
       snb_09             na1_d25f.
       snb_10             na1_d25f.
       snb_11             na1_d25f.
       snb_12             na1_d25f.
       snb_13             na1_d25f.
       snb_14             na1_d25f.
       snb_15             na1_d25f.
       snb_16             na1_d25f.
       snb_17             na1_d25f.
       snb_18             na1_d25f.
       snb_19             na1_d25f.
       snb_20             na1_d25f.
       snb_21             na1_d25f.
       snb_22             na1_d25f.
       snb_23             na1_d25f.
       snb_24             na1_d25f.
       snb_25             na1_d25f.
       snc_01             na1_d25f.
       snc_02             na1_d25f.
       snc_03             na1_d25f.
       snc_04             na1_d25f.
       snc_05             na1_d25f.
       snc_06             na1_d25f.
       snc_07             na1_d25f.
       snc_08             na1_d25f.
       snc_09             na1_d25f.
       snc_10             na1_d25f.
       snc_11             na1_d25f.
       snc_12             na1_d25f.
       snc_13             na1_d25f.
       snc_14             na1_d25f.
       snc_15             na1_d25f.
       snc_16             na1_d25f.
       snc_17             na1_d25f.
       snc_18             na1_d25f.
       snc_19             na1_d25f.
       snc_20             na1_d25f.
       snc_21             na1_d25f.
       snc_22             na1_d25f.
       snc_23             na1_d25f.
       snc_24             na1_d25f.
       snc_25             na1_d25f.
       snd_01             na1_d25f.
       snd_02             na1_d25f.
       snd_03             na1_d25f.
       snd_04             na1_d25f.
       snd_05             na1_d25f.
       snd_06             na1_d25f.
       snd_07             na1_d25f.
       snd_08             na1_d25f.
       snd_09             na1_d25f.
       snd_10             na1_d25f.
       snd_11             na1_d25f.
       snd_12             na1_d25f.
       snd_13             na1_d25f.
       snd_14             na1_d25f.
       snd_15             na1_d25f.
       snd_16             na1_d25f.
       snd_17             na1_d25f.
       snd_18             na1_d25f.
       snd_19             na1_d25f.
       snd_20             na1_d25f.
       snd_21             na1_d25f.
       snd_22             na1_d25f.
       snd_23             na1_d25f.
       snd_24             na1_d25f.
       snd_25             na1_d25f.
       wvarstrr           2.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(100)
                  sna_01 sna_02 sna_03 sna_04 sna_05 sna_06 sna_07 sna_08 sna_09 sna_10
                  sna_11 sna_12 sna_13 sna_14 sna_15 sna_16 sna_17 sna_18 sna_19 sna_20
                  sna_21 sna_22 sna_23 sna_24 sna_25 snb_01 snb_02 snb_03 snb_04 snb_05
                  snb_06 snb_07 snb_08 snb_09 snb_10 snb_11 snb_12 snb_13 snb_14 snb_15
                  snb_16 snb_17 snb_18 snb_19 snb_20 snb_21 snb_22 snb_23 snb_24 snb_25
                  snc_01 snc_02 snc_03 snc_04 snc_05 snc_06 snc_07 snc_08 snc_09 snc_10
                  snc_11 snc_12 snc_13 snc_14 snc_15 snc_16 snc_17 snc_18 snc_19 snc_20
                  snc_21 snc_22 snc_23 snc_24 snc_25 snd_01 snd_02 snd_03 snd_04 snd_05
                  snd_06 snd_07 snd_08 snd_09 snd_10 snd_11 snd_12 snd_13 snd_14 snd_15
                  snd_16 snd_17 snd_18 snd_19 snd_20 snd_21 snd_22 snd_23 snd_24 snd_25;
   DO  i=1 TO 100;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;
